@@ -738,7 +738,7 @@ def files_append( fp_source , fp_target = False ) :
 def files_restore( rpath = False , mode = "overwrite" ) :
 
     db_files = files_readallmeta( )
-    s_log.write( db_files )
+    #s_log.write( db_files )
     
     for db_file in db_files :
 
