@@ -162,8 +162,9 @@ def job_request( params = { } ) :
     #####################################################################
 
     payload = s_db.blob_get( )
-    payload_len=len( payload )
-    if(payload_len>0) : s_log.write( "PAYLOAD REQUEST "+str(payload_len))
+
+    #payload_len = len( payload )
+    #if( payload_len > 0 ) : s_log.write( "PAYLOAD REQUEST " + str( payload_len ) )
 
     #####################################################################
 
@@ -281,8 +282,9 @@ def job_response( jid ) :
         s_log.write( "ERROR EMPTY RES CONTENT" )
         return( False )
 
-    payload_len=len( res.content )
-    if(payload_len>0) : s_log.write( "PAYLOAD RESPONSE "+str(payload_len))
+    #payload_len=len( res.content )
+    #if(payload_len>0) : s_log.write( "PAYLOAD RESPONSE "+str(payload_len))
+    
     s_db.blob_set( res.content )
 
     # FIXME TODO we must have this before AND after the DB SET
