@@ -190,11 +190,13 @@ def pathnotallowed( p ) :
     return( True )
 
 
+
 def get_hashkeycontentdir( ) :
     # FIXME TODO should be coming from config
     fd = "/tmp/sapiadapter/sessions/"
 
-    if( dir_exists( "/data/" ) ) :
+    # FIXME TODO have this as a convenience function
+    if environ_isdockerrunning( ) and dir_exists( "/data/" ) :
         fd = "/data/sessions/"
 
     return( fd )
@@ -482,6 +484,10 @@ def parent_path( ) :
 
 ################
 
+def environ_isdockerrunning( ) :
+    return( "DOCKER_RUNNING" in os.environ )
+
+
 def environ_getall( ) :
     return( os.environ )
 
@@ -526,7 +532,7 @@ def sleep( t = 1 ) :
 
 def idle( ) :
     while True:
-        s_log.write("IDLE")
+        s_log.write( "IDLE" )
         time.sleep( 86400 )
 
 def datetime_now_db( td = 0 ) :
@@ -632,6 +638,10 @@ def file_changed( fp , ctime ) :
     if(not file_exists(fp)): return(False)
     return( file_ctime(fp)!=ctime)
 
+def file_rm( fp ) :
+    if( not file_exists( fp ) ) : return( False )
+    os.remove( fp )
+    return( True )
 
 def path_stem( p ) :
     fn = Path( p ).stem
